
#include <stdlib.h>
#include <stdio.h>
#include <stdarg.h>
#include <string.h>
#include <limits.h>
#include <fx.h>
#include <stdint.h>
#include <FXPNGIcon.h>

static int app_created;

#include "gui.h"


#include "actions.h"


   static FXFont *YQRZ_3;
    

static void label_set_text(gui_label_t *B, char *text)
{
  FXLabel *W= (FXLabel*) B->widget;
  W->setText(text);
}

static gui_label_class_t
 gui_label_class= {
  label_set_text,
};


  static FXFont *YQRZ_7;
    

class FYListItem : public FXListItem 
{
  FXDECLARE(FYListItem)
protected:
  FYListItem() : FXListItem() { }
public:
  FYListItem(const FXString& text,FXIcon* ic, void *pdata)
   : FXListItem(text,ic,NULL)
  { data_p= pdata; }
  FYListItem(const FXString& text,FXIcon* ic, int idata)
   : FXListItem(text,ic,NULL)
  { data_i= idata; }
  FYListItem(const FXString& text,FXIcon* ic, double fdata)
   : FXListItem(text,ic,NULL)
  { data_f= fdata; }
  ~FYListItem() { }
// These could be in a union, but who cares about space
  int data_i;
  double data_f;
  void *data_p;
};


FXIMPLEMENT(FYListItem,FXListItem,NULL,0)




static void clear_selection
  (FXList *L)
{
  int i;
  int N= L->getNumItems();
  for(i=0;i<N;i++)
    L->deselectItem(i);
}

static FYListItem* get_selected(FXList *L)
{
   int i, N= L->getNumItems();
   for(i=0;i<N;i++)
     if (L->isItemSelected(i))
       return (FYListItem*) L->getItem(i);
   return 0;
}




static inline FXList* list(gui_intlist_t *IL)
{
  return (FXList*) (IL->widget);
}

static int intlist_get_selected
   (gui_intlist_t* IL, int *ret)
{
  FYListItem *item= get_selected(list(IL));
  if (item) { *ret= item->data_i; return 1; }
  return 0;
}

static void intlist_clear(gui_intlist_t* IL)
{
  list(IL)->clearItems();
}

static int intlist_find_item(gui_intlist_t *IL, int key)
{
  int i;
  FXList* L= list(IL);
  int N= L->getNumItems();
  for(i=0;i<N;i++)
    {
        FYListItem *it= (FYListItem*) L->getItem(i);
        if (it->data_i==key) return i;
    }
  return -1;
}

static int intlist_select_item
  (gui_intlist_t *IL, int key,int sel)
{
  int i= intlist_find_item(IL, key); 
  if (i==-1) return 0;
  if (sel) list(IL)->selectItem(i);
  else list(IL)->deselectItem(i); 
  return 1;
}


static void intlist_append_item
  (gui_intlist_t *IL, const char *text, int key)
{
  list(IL)->appendItem(new FYListItem(text, NULL,key));
}

static void intlist_prepend_item
  (gui_intlist_t *IL, const char *text, int key)
{
  list(IL)->prependItem(new FYListItem(text, NULL,key));
}

static void intlist_insert_item
  (gui_intlist_t *IL, int poskey, const char *text, int key)
{
  int i= intlist_find_item(IL, poskey);
  if (i!=-1)
    list(IL)->insertItem(i, new FYListItem(text, NULL, key));
  else
    list(IL)->appendItem(new FYListItem(text, NULL, key));
}

static void intlist_clear_selection(gui_intlist_t *IL)
{
  clear_selection(list(IL));
}

static void intlist_remove_item(gui_intlist_t *IL, int key)
{
  int i= intlist_find_item(IL, key);
  if (i==-1) return ;
  list(IL)->removeItem(i);
}

static gui_intlist_class_t gui_intlist_class=
{
   intlist_get_selected,
   intlist_select_item,
   intlist_clear_selection,
   intlist_append_item,
   intlist_prepend_item,
   intlist_insert_item,
   intlist_remove_item,
   intlist_clear,
};

  static FXFont *YQRZ_13;
      static FXFont *YQRZ_17;
    

static void button_set_text(gui_button_t *B,const char *text)
{
  FXButton *W= (FXButton*) B->widget;
  W->setText(text);
}

static gui_button_class_t
 gui_button_class= {
  button_set_text,
};




static void text_entry_set_text(gui_text_entry_t *B, char *text)
{
  FXTextField *W= (FXTextField*) B->widget;
  W->setText(text);
}

static char* text_entry_get_text(gui_text_entry_t *B)
{
  FXTextField *W= (FXTextField*) B->widget;
  FXString S= W->getText();
  return strdup(S.text());
}

static 
 gui_text_entry_class_t gui_text_entry_class= {
   text_entry_set_text,
   text_entry_get_text
};



static void check_box_get_value
     (gui_check_box_t *CB,int *R)
{
  FXCheckButton *W= (FXCheckButton*) (CB->widget);
  // I know, I`m checking against TRUE but this is necessary
  // since the library has also a MAYBE value. peh.
  if (W->getCheck()==TRUE)
   *R= 1;
  else *R= 0;
}

static void check_box_set_value(gui_check_box_t *CB, int V)
{
  FXCheckButton *W= (FXCheckButton*) (CB->widget);
  if (V) W->setCheck(TRUE); else W->setCheck(FALSE);
}

static gui_check_box_class_t gui_check_box_class= {
  check_box_get_value,
  check_box_set_value,
};




static void gui_message_console_print
   (gui_message_console_t *mc, const char * fmt,...)
{
   int size=200; char *message; int len; char *atmp;
   va_list ap;
   message= (char*) malloc(size);
   while(1) {
     va_start(ap,fmt);
     len= vsnprintf(message,size, fmt, ap);
     va_end(ap);
     if (len<0) size*= 2;
     else if (len<size) break;
     else size= len+2;
     message= (char*) realloc(atmp= message, size);
     if (!message) {
        free(atmp);
        message= (char*) fmt;
        break;
     }
  } 
  FXText *W= (FXText*) mc->widget;
  W->appendText(message, strlen(message));
  if (message!=fmt) free(message);
   // argh, AUTOSCROLL doesn`t work yet. see
   // http://ruby.11.n6.nabble.com/TEXT-AUTOSCROLL-in-FXText-with-usage-of-FXDataTarget-td3510118.html
  W->makePositionVisible(W->getLength()-1);
}


static void gui_message_console_append
   (gui_message_console_t *mc, const char * str, size_t len)
{
  FXText *W= (FXText*) mc->widget;
  W->appendText(str, len);
   // argh, AUTOSCROLL doesn`t work yet. see
   // http://ruby.11.n6.nabble.com/TEXT-AUTOSCROLL-in-FXText-with-usage-of-FXDataTarget-td3510118.html
  W->makePositionVisible(W->getLength()-1);
}



static void gui_message_console_clear(gui_message_console_t *mc)
{
  FXText *W= (FXText*) mc->widget;
  W->removeText(0, W->getLength()); 
}

static gui_message_console_class_t 
  gui_message_console_class= 
{
  gui_message_console_print,
  gui_message_console_clear,
  gui_message_console_append,
};



typedef struct {
   int (*execute)(void*);
   void (*close)(void*);
} gui_generic_dialog_class_t;

typedef struct {
  void *cls;
  void *widget;
} gui_ptrpair_t;

static int dialog_execute(void *form)
{
  gui_ptrpair_t *W= (gui_ptrpair_t*) form;
  FXTopWindow *win= (FXTopWindow*) W->widget;
  win->create();
  win->show(PLACEMENT_SCREEN);
  FXApp::instance()->refresh();
  return FXApp::instance()->runModalFor(win);
}

static void dialog_close(void *form)
{
  gui_ptrpair_t *W= (gui_ptrpair_t*) form;
  FXTopWindow *win= (FXTopWindow*) W->widget;
  FXApp::instance()->stopModal(0);
  delete win;
  free(form);
}

static gui_generic_dialog_class_t gui_dialog_class= {
   dialog_execute,
   dialog_close
};

  static FXFont *YQRZ_117;
      static FXFont *YQRZ_148;
    
 
 
 

 class VFLL1: public FXMainWindow
 {
  FXDECLARE(VFLL1)
 public:
  enum { ID_FIRST= FXMainWindow::ID_LAST,
         ID_SELF,
         
  YQRZ_5,


  YQRZ_15,


 YQRZ_22,


 YQRZ_27,


 YQRZ_32,


 YQRZ_37,

      


      



  


  


 YQRZ_75,


 YQRZ_80,


 YQRZ_91,


 YQRZ_101,


 YQRZ_106,

 };
  
  


  


  FXList *ud_unmounted;


  long YQRZ_8(FXObject *object,FXSelector sel,void* arg);
  long YQRZ_9(FXObject *object,FXSelector sel,void* arg);



  


  FXList *ud_mounted;


  long YQRZ_18(FXObject *object,FXSelector sel,void* arg);
  long YQRZ_19(FXObject *object,FXSelector sel,void* arg);



  long YQRZ_25(FXObject *object,FXSelector sel, void *arg);
  



  long YQRZ_30(FXObject *object,FXSelector sel, void *arg);
  



  long YQRZ_35(FXObject *object,FXSelector sel, void *arg);
  



  long YQRZ_40(FXObject *object,FXSelector sel, void *arg);
  



  



FXTextField *file_browser;



  



  



FXTextField *mount_prg;



  


  FXCheckButton* opexec;
  


  FXCheckButton* opnoatime;
  



  long YQRZ_78(FXObject *object,FXSelector sel, void *arg);
  



  long YQRZ_83(FXObject *object,FXSelector sel, void *arg);
  



  FXText *message;



  long YQRZ_94(FXObject *object,FXSelector sel, void *arg);
  



  FXText *about;



  long YQRZ_104(FXObject *object,FXSelector sel, void *arg);
  



  long YQRZ_109(FXObject *object,FXSelector sel, void *arg);
  


  VFLL1(FXApp* a,const FXString& name,
         FXIcon *ic,FXIcon *mi,FXuint opts,
         FXint x,FXint y,FXint w,FXint h,
         FXint pl,FXint pr,FXint pt,FXint pb,
         FXint hs,FXint vs);
  virtual ~VFLL1();
  VFLL1() : FXMainWindow() { }
  long handle_close(FXObject *object,FXSelector sel, void *arg);
 };

 FXDEFMAP(VFLL1) YQRZ_114 []= {
  FXMAPFUNC(SEL_CLOSE, VFLL1::ID_SELF, VFLL1::handle_close),
  
  
     FXMAPFUNC(SEL_CLICKED,VFLL1::YQRZ_5,VFLL1::YQRZ_8),
  
     FXMAPFUNC(SEL_DOUBLECLICKED,VFLL1::YQRZ_5,VFLL1::YQRZ_9),


  
     FXMAPFUNC(SEL_CLICKED,VFLL1::YQRZ_15,VFLL1::YQRZ_18),
  
     FXMAPFUNC(SEL_DOUBLECLICKED,VFLL1::YQRZ_15,VFLL1::YQRZ_19),


 
    FXMAPFUNC(SEL_COMMAND, VFLL1::YQRZ_22, VFLL1::YQRZ_25),


 
    FXMAPFUNC(SEL_COMMAND, VFLL1::YQRZ_27, VFLL1::YQRZ_30),


 
    FXMAPFUNC(SEL_COMMAND, VFLL1::YQRZ_32, VFLL1::YQRZ_35),


 
    FXMAPFUNC(SEL_COMMAND, VFLL1::YQRZ_37, VFLL1::YQRZ_40),


 


 


  


  


 
    FXMAPFUNC(SEL_COMMAND, VFLL1::YQRZ_75, VFLL1::YQRZ_78),


 
    FXMAPFUNC(SEL_COMMAND, VFLL1::YQRZ_80, VFLL1::YQRZ_83),


 
    FXMAPFUNC(SEL_COMMAND, VFLL1::YQRZ_91, VFLL1::YQRZ_94),


 
    FXMAPFUNC(SEL_COMMAND, VFLL1::YQRZ_101, VFLL1::YQRZ_104),


 
    FXMAPFUNC(SEL_COMMAND, VFLL1::YQRZ_106, VFLL1::YQRZ_109),


 }; 

 FXIMPLEMENT(VFLL1, FXMainWindow, YQRZ_114, ARRAYNUMBER(YQRZ_114))

 // FIXME: the argument names must be changed so that
 // we can have widgets called 'y' etc.
 VFLL1::VFLL1(
         FXApp* a,const FXString& name,
         FXIcon *ic,FXIcon *mi,FXuint opts,
         FXint x,FXint y,FXint w,FXint h,
         FXint pl,FXint pr,FXint pt,FXint pb,
         FXint hs,FXint vs) :
               FXMainWindow(a,name, ic,mi,opts,
                            x,y,w,h, pl,pr,pt,pb, hs,vs)

 {
   setTarget(this);
   setSelector(ID_SELF);
   
  FXTabBook *YQRZ_113;
  YQRZ_113=  new FXTabBook(this,
           NULL, 0, // selector stuff

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        LAYOUT_FILL_Y |  0, // FIXME: do the tab-side stuff.

        0,0,0,0, // xywh
        DEFAULT_SPACING,
        DEFAULT_SPACING,
        DEFAULT_SPACING,
        DEFAULT_SPACING);

   
  FXTabItem *YQRZ_43;
  YQRZ_43= new FXTabItem( YQRZ_113,
                           "Devices", NULL);
  // FIXME: do the fonts here

  FXVerticalFrame *YQRZ_42= new
    FXVerticalFrame( YQRZ_113,
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        LAYOUT_FILL_Y |
        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_SPACING,
        DEFAULT_SPACING);



  FXLabel *YQRZ_1;

  YQRZ_1= 
    new FXLabel(YQRZ_42,
      "Unmounted",
      NULL,

        LAYOUT_CENTER_X |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        0 |

        0 |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  
     FXFontDesc YQRZ_2;
     YQRZ_1->getFont()->getFontDesc(YQRZ_2);
  

  
     YQRZ_2.size= 14 * 10;
  

  

  
    YQRZ_3= new FXFont(FXApp::instance(), YQRZ_2);
    YQRZ_1->setFont(YQRZ_3);
    
  



   FXList *YQRZ_4; 

   YQRZ_4= ud_unmounted = new FXList(YQRZ_42,
        this
           ,
        YQRZ_5
           ,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        LAYOUT_FILL_Y 
                 ,0,0,0,0); // xywh


  
     FXFontDesc YQRZ_6;
     YQRZ_4->getFont()->getFontDesc(YQRZ_6);
  

  
     YQRZ_6.size= 12 * 10;
  

  

  
    YQRZ_7= new FXFont(FXApp::instance(), YQRZ_6);
    YQRZ_4->setFont(YQRZ_7);
    
  




  FXLabel *YQRZ_11;

  YQRZ_11= 
    new FXLabel(YQRZ_42,
      "Mounted",
      NULL,

        LAYOUT_CENTER_X |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        0 |

        0 |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  
     FXFontDesc YQRZ_12;
     YQRZ_11->getFont()->getFontDesc(YQRZ_12);
  

  
     YQRZ_12.size= 14 * 10;
  

  

  
    YQRZ_13= new FXFont(FXApp::instance(), YQRZ_12);
    YQRZ_11->setFont(YQRZ_13);
    
  



   FXList *YQRZ_14; 

   YQRZ_14= ud_mounted = new FXList(YQRZ_42,
        this
           ,
        YQRZ_15
           ,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        LAYOUT_FILL_Y 
                 ,0,0,0,0); // xywh


  
     FXFontDesc YQRZ_16;
     YQRZ_14->getFont()->getFontDesc(YQRZ_16);
  

  
     YQRZ_16.size= 12 * 10;
  

  

  
    YQRZ_17= new FXFont(FXApp::instance(), YQRZ_16);
    YQRZ_14->setFont(YQRZ_17);
    
  



  FXHorizontalFrame *YQRZ_41= new
    FXHorizontalFrame( YQRZ_42,
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        0 |
        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_SPACING,
        DEFAULT_SPACING);



  FXButton *YQRZ_21;

  YQRZ_21= 
    new FXButton(YQRZ_41,
      "Unmount",
      NULL,
      this ,
      YQRZ_22 ,

        LAYOUT_RIGHT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        FRAME_RAISED|FRAME_THICK |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y 

        

        
        
        ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  


   

         



  FXButton *YQRZ_26;

  YQRZ_26= 
    new FXButton(YQRZ_41,
      " Mount ",
      NULL,
      this ,
      YQRZ_27 ,

        LAYOUT_RIGHT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        FRAME_RAISED|FRAME_THICK |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y 

        

        
        
        ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  


   

         



  FXButton *YQRZ_31;

  YQRZ_31= 
    new FXButton(YQRZ_41,
      "Refresh",
      NULL,
      this ,
      YQRZ_32 ,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        FRAME_RAISED|FRAME_THICK |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y 

        

        
        
        ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  


   

         



  FXButton *YQRZ_36;

  YQRZ_36= 
    new FXButton(YQRZ_41,
      "Options",
      NULL,
      this ,
      YQRZ_37 ,

        LAYOUT_CENTER_X |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        FRAME_RAISED|FRAME_THICK |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y 

        

        
        
        ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  


   

         


  FXTabItem *YQRZ_86;
  YQRZ_86= new FXTabItem( YQRZ_113,
                           "Settings", NULL);
  // FIXME: do the fonts here

  FXVerticalFrame *YQRZ_85= new
    FXVerticalFrame( YQRZ_113,
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        LAYOUT_FILL_Y |
        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_SPACING,
        DEFAULT_SPACING);


  FXHorizontalFrame *YQRZ_50= new
    FXHorizontalFrame( YQRZ_85,
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        0 |
        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_SPACING,
        DEFAULT_SPACING);



  FXLabel *YQRZ_44;

  YQRZ_44= 
    new FXLabel(YQRZ_50,
      "File browser:     ",
      NULL,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        0 |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  




  FXTextField *YQRZ_47;

  file_browser = YQRZ_47= 
    new FXTextField(YQRZ_50,
      40,
       NULL,
       0,
 
     LAYOUT_LEFT |
     LAYOUT_TOP |
     LAYOUT_SIDE_TOP |
     LAYOUT_FILL_X |
     0 |

    FRAME_SUNKEN|FRAME_THICK |
    JUSTIFY_LEFT |
    JUSTIFY_CENTER_Y

        ,

    0,0,0,0, // x,y,w,h

    DEFAULT_PAD,
    DEFAULT_PAD,
    DEFAULT_PAD,
    DEFAULT_PAD);




  FXLabel *YQRZ_51;

  YQRZ_51= 
    new FXLabel(YQRZ_85,
      "Default is /usr/bin/xdg-open",
      NULL,

        LAYOUT_RIGHT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        0 |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  



  FXHorizontalFrame *YQRZ_60= new
    FXHorizontalFrame( YQRZ_85,
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        0 |
        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_SPACING,
        DEFAULT_SPACING);



  FXLabel *YQRZ_54;

  YQRZ_54= 
    new FXLabel(YQRZ_60,
      "Mount program:",
      NULL,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        0 |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  




  FXTextField *YQRZ_57;

  mount_prg = YQRZ_57= 
    new FXTextField(YQRZ_60,
      40,
       NULL,
       0,
 
     LAYOUT_LEFT |
     LAYOUT_TOP |
     LAYOUT_SIDE_TOP |
     LAYOUT_FILL_X |
     0 |

    FRAME_SUNKEN|FRAME_THICK |
    JUSTIFY_LEFT |
    JUSTIFY_CENTER_Y

        ,

    0,0,0,0, // x,y,w,h

    DEFAULT_PAD,
    DEFAULT_PAD,
    DEFAULT_PAD,
    DEFAULT_PAD);




  FXLabel *YQRZ_61;

  YQRZ_61= 
    new FXLabel(YQRZ_85,
      "Default is /usr/bin/pmount",
      NULL,

        LAYOUT_RIGHT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        0 |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  



  FXCheckButton *YQRZ_64;
  YQRZ_64= opexec = new FXCheckButton(
             YQRZ_85, "Mount with 'exec' flag",
                     NULL,
              0,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        FRAME_NONE |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

             0,0,0,0, // xywh
             DEFAULT_PAD,
             DEFAULT_PAD,
             DEFAULT_PAD,
             DEFAULT_PAD);

  

  

  

  



  FXCheckButton *YQRZ_69;
  YQRZ_69= opnoatime = new FXCheckButton(
             YQRZ_85, "Mount with 'noatime' flag",
                     NULL,
              0,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        FRAME_NONE |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

             0,0,0,0, // xywh
             DEFAULT_PAD,
             DEFAULT_PAD,
             DEFAULT_PAD,
             DEFAULT_PAD);

  

  

  

  



  FXHorizontalFrame *YQRZ_84= new
    FXHorizontalFrame( YQRZ_85,
        LAYOUT_LEFT |
        LAYOUT_BOTTOM |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        0 |
        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_SPACING,
        DEFAULT_SPACING);



  FXButton *YQRZ_74;

  YQRZ_74= 
    new FXButton(YQRZ_84,
      "Save",
      NULL,
      this ,
      YQRZ_75 ,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        FRAME_RAISED|FRAME_THICK |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y 

        

        
        
        ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  


   

         



  FXButton *YQRZ_79;

  YQRZ_79= 
    new FXButton(YQRZ_84,
      "Reload",
      NULL,
      this ,
      YQRZ_80 ,

        LAYOUT_RIGHT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        FRAME_RAISED|FRAME_THICK |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y 

        

        
        
        ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  


   

         


  FXTabItem *YQRZ_96;
  YQRZ_96= new FXTabItem( YQRZ_113,
                           "Messages", NULL);
  // FIXME: do the fonts here

  FXVerticalFrame *YQRZ_95= new
    FXVerticalFrame( YQRZ_113,
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        LAYOUT_FILL_Y |
        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_SPACING,
        DEFAULT_SPACING);



  FXText *YQRZ_87;
  YQRZ_87= message = new FXText(
       YQRZ_95, NULL,0, // target & selector
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        LAYOUT_FILL_Y |
        TEXT_FIXEDWRAP |
        VSCROLLER_ALWAYS |
        TEXT_READONLY | TEXT_AUTOSCROLL |
        0,
     0,0,0,0,  // x,y,w,h
             // FIXME: these are given as number constants in the
             // FXText constructor. Nothing symbolic like DEFAULT_PAD
             // etc. is used. So, I will do the same unwillingly.
     3,
     3,
     2,
     2);

  

  

  

  




  FXButton *YQRZ_90;

  YQRZ_90= 
    new FXButton(YQRZ_95,
      "Clear",
      NULL,
      this ,
      YQRZ_91 ,

        LAYOUT_CENTER_X |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        FRAME_RAISED|FRAME_THICK |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y 

        

        
        
        ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  


   

         


  FXTabItem *YQRZ_112;
  YQRZ_112= new FXTabItem( YQRZ_113,
                           "About", NULL);
  // FIXME: do the fonts here

  FXVerticalFrame *YQRZ_111= new
    FXVerticalFrame( YQRZ_113,
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        LAYOUT_FILL_Y |
        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_SPACING,
        DEFAULT_SPACING);



  FXText *YQRZ_97;
  YQRZ_97= about = new FXText(
       YQRZ_111, NULL,0, // target & selector
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        LAYOUT_FILL_Y |
        TEXT_WORDWRAP |
        VSCROLLER_ALWAYS |
        TEXT_READONLY | TEXT_AUTOSCROLL |
        0,
     0,0,0,0,  // x,y,w,h
             // FIXME: these are given as number constants in the
             // FXText constructor. Nothing symbolic like DEFAULT_PAD
             // etc. is used. So, I will do the same unwillingly.
     3,
     3,
     2,
     2);

  

  

  

  



  FXHorizontalFrame *YQRZ_110= new
    FXHorizontalFrame( YQRZ_111,
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        0 |
        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_SPACING,
        DEFAULT_SPACING);



  FXButton *YQRZ_100;

  YQRZ_100= 
    new FXButton(YQRZ_110,
      "Copyright",
      NULL,
      this ,
      YQRZ_101 ,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        FRAME_RAISED|FRAME_THICK |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y 

        

        
        
        ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  


   

         



  FXButton *YQRZ_105;

  YQRZ_105= 
    new FXButton(YQRZ_110,
      "Help",
      NULL,
      this ,
      YQRZ_106 ,

        LAYOUT_RIGHT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        FRAME_RAISED|FRAME_THICK |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y 

        

        
        
        ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  


   

         




 }
 VFLL1:: ~ VFLL1() { }
 long VFLL1::handle_close
    (FXObject *object,FXSelector sel, void *arg)
 {
    /* window closing code would go here */
    return 0;
 } 
 

 long VFLL1::YQRZ_8
    (FXObject *object,FXSelector sel, void *arg)
    {
      FXList *YQRZ_10= (FXList*)(object);
      int clicked_item= (intptr_t) (arg);
      FYListItem *item= (FYListItem*) (YQRZ_10->getItem(clicked_item));

      int clicked_key = item->data_i;
      
      
      
       click_device(clicked_key, 'u'); 
      return 1;
    }


 long VFLL1::YQRZ_9
    (FXObject *object,FXSelector sel, void *arg)
    {
      FXList *YQRZ_10= (FXList*)(object);
      int clicked_item= (intptr_t) (arg);
      FYListItem *item= (FYListItem*) (YQRZ_10->getItem(clicked_item));

      int clicked_key = item->data_i;
      
      
      
       double_click_device(clicked_key,'m'); 
      return 1;
    }





 long VFLL1::YQRZ_18
    (FXObject *object,FXSelector sel, void *arg)
    {
      FXList *YQRZ_20= (FXList*)(object);
      int clicked_item= (intptr_t) (arg);
      FYListItem *item= (FYListItem*) (YQRZ_20->getItem(clicked_item));

      int clicked_key = item->data_i;
      
      
      
       click_device(clicked_key, 'm'); 
      return 1;
    }


 long VFLL1::YQRZ_19
    (FXObject *object,FXSelector sel, void *arg)
    {
      FXList *YQRZ_20= (FXList*)(object);
      int clicked_item= (intptr_t) (arg);
      FYListItem *item= (FYListItem*) (YQRZ_20->getItem(clicked_item));

      int clicked_key = item->data_i;
      
      
      
       double_click_device(clicked_key,'u'); 
      return 1;
    }





  long VFLL1::YQRZ_25
    (FXObject *object,FXSelector sel, void *arg)
       {  click_mount_button('u'); return 1; }





  long VFLL1::YQRZ_30
    (FXObject *object,FXSelector sel, void *arg)
       {  click_mount_button('m'); return 1; }





  long VFLL1::YQRZ_35
    (FXObject *object,FXSelector sel, void *arg)
       {  click_refresh();  return 1; }





  long VFLL1::YQRZ_40
    (FXObject *object,FXSelector sel, void *arg)
       {  click_devopt();  return 1; }











  


  




  long VFLL1::YQRZ_78
    (FXObject *object,FXSelector sel, void *arg)
       {  click_save_settings();  return 1; }





  long VFLL1::YQRZ_83
    (FXObject *object,FXSelector sel, void *arg)
       {  click_reload_settings(); return 1; }





  long VFLL1::YQRZ_94
    (FXObject *object,FXSelector sel, void *arg)
       {  clear_messages();  return 1; }





  long VFLL1::YQRZ_104
    (FXObject *object,FXSelector sel, void *arg)
       {  about_box(1);  return 1; }





  long VFLL1::YQRZ_109
    (FXObject *object,FXSelector sel, void *arg)
       {  about_box(2);  return 1; }







 class VFLL2: public FXTopWindow
 {
  FXDECLARE(VFLL2)
 public:
  enum { ID_FIRST= FXTopWindow::ID_LAST,
         ID_SELF,
               



  YQRZ_150,

      



  


  


 YQRZ_184,


 YQRZ_189,

 };
  

  



  



  FXLabel *vendor;



  



  FXLabel *model;



  



  FXLabel *serial;



  



FXTextField *pretty_name;



  


  FXList *parts;


  long YQRZ_153(FXObject *object,FXSelector sel,void* arg);
  



  



  FXLabel *selpart;



  



FXTextField *mount_label;


  FXCheckButton* opexec;
  


  FXCheckButton* opnoatime;
  



  long YQRZ_187(FXObject *object,FXSelector sel, void *arg);
  



  long YQRZ_192(FXObject *object,FXSelector sel, void *arg);
  


  VFLL2(FXWindow* own,const FXString& name,
         FXIcon *ic,FXIcon *mi,FXuint opts,
         FXint x,FXint y,FXint w,FXint h,
         FXint pl,FXint pr,FXint pt,FXint pb,
         FXint hs,FXint vs);
  virtual ~VFLL2();
  VFLL2() : FXTopWindow() { }
  void dialog_done(int value);
  long handle_close(FXObject *object,FXSelector sel, void *arg);
 };

 FXDEFMAP(VFLL2) YQRZ_196 []= {
  FXMAPFUNC(SEL_CLOSE, VFLL2::ID_SELF, VFLL2::handle_close),
  
 


  
     FXMAPFUNC(SEL_CLICKED,VFLL2::YQRZ_150,VFLL2::YQRZ_153),
  


 


  


  


 
    FXMAPFUNC(SEL_COMMAND, VFLL2::YQRZ_184, VFLL2::YQRZ_187),


 
    FXMAPFUNC(SEL_COMMAND, VFLL2::YQRZ_189, VFLL2::YQRZ_192),


 }; 

 FXIMPLEMENT(VFLL2, FXTopWindow, YQRZ_196, ARRAYNUMBER(YQRZ_196))
 
 // FIXME: the argument names must be changed so that
 // we can have widgets called 'y' etc.
 VFLL2::VFLL2(
         FXWindow* YQRZ_197,const FXString& YQRZ_198,
         FXIcon *YQRZ_199,FXIcon *YQRZ_200,FXuint YQRZ_201,
         FXint YQRZ_202,FXint YQRZ_203,FXint YQRZ_204,FXint YQRZ_205,
         FXint YQRZ_206,FXint YQRZ_207,FXint YQRZ_208,FXint YQRZ_209,
         FXint YQRZ_210,FXint YQRZ_211) :
               FXTopWindow(YQRZ_197,YQRZ_198, YQRZ_199,YQRZ_200,YQRZ_201,
                            YQRZ_202,YQRZ_203,YQRZ_204,YQRZ_205,
                            YQRZ_206,YQRZ_207,YQRZ_208,YQRZ_209,
                            YQRZ_210,YQRZ_211)
 {
   setTarget(this);
   setSelector(ID_SELF);
   
  FXVerticalFrame *YQRZ_194= new
    FXVerticalFrame( this,
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        LAYOUT_FILL_Y |
        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_SPACING,
        DEFAULT_SPACING);



  FXLabel *YQRZ_115;

  YQRZ_115= 
    new FXLabel(YQRZ_194,
      "Device",
      NULL,

        LAYOUT_CENTER_X |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        0 |

        0 |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  
     FXFontDesc YQRZ_116;
     YQRZ_115->getFont()->getFontDesc(YQRZ_116);
  

  
     YQRZ_116.size= 12 * 10;
  

  

  
    YQRZ_117= new FXFont(FXApp::instance(), YQRZ_116);
    YQRZ_115->setFont(YQRZ_117);
    
  



  FXHorizontalFrame *YQRZ_124= new
    FXHorizontalFrame( YQRZ_194,
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        0 |
        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_SPACING,
        DEFAULT_SPACING);



  FXLabel *YQRZ_118;

  YQRZ_118= 
    new FXLabel(YQRZ_124,
      "Vendor     ",
      NULL,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        0 |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  




  FXLabel *YQRZ_121;

  YQRZ_121= vendor =
    new FXLabel(YQRZ_124,
      "X",
      NULL,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        0 |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  



  FXHorizontalFrame *YQRZ_131= new
    FXHorizontalFrame( YQRZ_194,
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        0 |
        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_SPACING,
        DEFAULT_SPACING);



  FXLabel *YQRZ_125;

  YQRZ_125= 
    new FXLabel(YQRZ_131,
      "Model      ",
      NULL,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        0 |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  




  FXLabel *YQRZ_128;

  YQRZ_128= model =
    new FXLabel(YQRZ_131,
      "X",
      NULL,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        0 |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  



  FXHorizontalFrame *YQRZ_138= new
    FXHorizontalFrame( YQRZ_194,
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        0 |
        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_SPACING,
        DEFAULT_SPACING);



  FXLabel *YQRZ_132;

  YQRZ_132= 
    new FXLabel(YQRZ_138,
      "Serial      ",
      NULL,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        0 |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  




  FXLabel *YQRZ_135;

  YQRZ_135= serial =
    new FXLabel(YQRZ_138,
      "X",
      NULL,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        0 |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  



  FXHorizontalFrame *YQRZ_145= new
    FXHorizontalFrame( YQRZ_194,
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        0 |
        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_SPACING,
        DEFAULT_SPACING);



  FXLabel *YQRZ_139;

  YQRZ_139= 
    new FXLabel(YQRZ_145,
      "Device Name",
      NULL,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        0 |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  




  FXTextField *YQRZ_142;

  pretty_name = YQRZ_142= 
    new FXTextField(YQRZ_145,
      40,
       NULL,
       0,
 
     LAYOUT_LEFT |
     LAYOUT_TOP |
     LAYOUT_SIDE_TOP |
     LAYOUT_FILL_X |
     0 |

    FRAME_SUNKEN|FRAME_THICK |
    JUSTIFY_LEFT |
    JUSTIFY_CENTER_Y

        ,

    0,0,0,0, // x,y,w,h

    DEFAULT_PAD,
    DEFAULT_PAD,
    DEFAULT_PAD,
    DEFAULT_PAD);




  FXLabel *YQRZ_146;

  YQRZ_146= 
    new FXLabel(YQRZ_194,
      "Partitions",
      NULL,

        LAYOUT_CENTER_X |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        0 |

        0 |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  
     FXFontDesc YQRZ_147;
     YQRZ_146->getFont()->getFontDesc(YQRZ_147);
  

  
     YQRZ_147.size= 12 * 10;
  

  

  
    YQRZ_148= new FXFont(FXApp::instance(), YQRZ_147);
    YQRZ_146->setFont(YQRZ_148);
    
  



  FXHorizontalFrame *YQRZ_182= new
    FXHorizontalFrame( YQRZ_194,
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        LAYOUT_FILL_Y |
        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_SPACING,
        DEFAULT_SPACING);


  FXVerticalFrame *YQRZ_156= new
    FXVerticalFrame( YQRZ_182,
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        LAYOUT_FILL_Y |
        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_SPACING,
        DEFAULT_SPACING);


   FXList *YQRZ_149; 

   YQRZ_149= parts = new FXList(YQRZ_156,
        this
           ,
        YQRZ_150
           ,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        LAYOUT_FILL_Y 
                 ,0,0,0,0); // xywh


  

  

  

  



  FXVerticalFrame *YQRZ_181= new
    FXVerticalFrame( YQRZ_182,
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        LAYOUT_FILL_Y |
        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_SPACING,
        DEFAULT_SPACING);


  FXHorizontalFrame *YQRZ_163= new
    FXHorizontalFrame( YQRZ_181,
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |
        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_SPACING,
        DEFAULT_SPACING);



  FXLabel *YQRZ_157;

  YQRZ_157= 
    new FXLabel(YQRZ_163,
      "Selected Partition: ",
      NULL,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        0 |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  




  FXLabel *YQRZ_160;

  YQRZ_160= selpart =
    new FXLabel(YQRZ_163,
      "",
      NULL,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        0 |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  



  FXHorizontalFrame *YQRZ_170= new
    FXHorizontalFrame( YQRZ_181,
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        0 |
        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_SPACING,
        DEFAULT_SPACING);



  FXLabel *YQRZ_164;

  YQRZ_164= 
    new FXLabel(YQRZ_170,
      "Mount Label:",
      NULL,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        0 |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  




  FXTextField *YQRZ_167;

  mount_label = YQRZ_167= 
    new FXTextField(YQRZ_170,
      40,
       NULL,
       0,
 
     LAYOUT_LEFT |
     LAYOUT_TOP |
     LAYOUT_SIDE_TOP |
     LAYOUT_FILL_X |
     0 |

    FRAME_SUNKEN|FRAME_THICK |
    JUSTIFY_LEFT |
    JUSTIFY_CENTER_Y

        ,

    0,0,0,0, // x,y,w,h

    DEFAULT_PAD,
    DEFAULT_PAD,
    DEFAULT_PAD,
    DEFAULT_PAD);



  FXCheckButton *YQRZ_171;
  YQRZ_171= opexec = new FXCheckButton(
             YQRZ_181, "Mount with 'exec' flag",
                     NULL,
              0,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        FRAME_NONE |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

             0,0,0,0, // xywh
             DEFAULT_PAD,
             DEFAULT_PAD,
             DEFAULT_PAD,
             DEFAULT_PAD);

  

  

  

  



  FXCheckButton *YQRZ_176;
  YQRZ_176= opnoatime = new FXCheckButton(
             YQRZ_181, "Mount with 'noatime' flag",
                     NULL,
              0,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        FRAME_NONE |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

             0,0,0,0, // xywh
             DEFAULT_PAD,
             DEFAULT_PAD,
             DEFAULT_PAD,
             DEFAULT_PAD);

  

  

  

  



  FXHorizontalFrame *YQRZ_193= new
    FXHorizontalFrame( YQRZ_194,
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        0 |
        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_SPACING,
        DEFAULT_SPACING);



  FXButton *YQRZ_183;

  YQRZ_183= 
    new FXButton(YQRZ_193,
      "Apply",
      NULL,
      this ,
      YQRZ_184 ,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        FRAME_RAISED|FRAME_THICK |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y 

        

        
        
        ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  


   

         



  FXButton *YQRZ_188;

  YQRZ_188= 
    new FXButton(YQRZ_193,
      "Cancel",
      NULL,
      this ,
      YQRZ_189 ,

        LAYOUT_RIGHT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        FRAME_RAISED|FRAME_THICK |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y 

        

        
        
        ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  


   

         


 }
 VFLL2:: ~ VFLL2() { }
 long VFLL2::handle_close
    (FXObject *object,FXSelector sel, void *arg)
 {
    /* window closing code would go here */
    return 0;
 } 
 void VFLL2::dialog_done(int value)
 {
   FXApp::instance()->stopModal(value);
 }
 





 long VFLL2::YQRZ_153
    (FXObject *object,FXSelector sel, void *arg)
    {
      FXList *YQRZ_155= (FXList*)(object);
      int clicked_item= (intptr_t) (arg);
      FYListItem *item= (FYListItem*) (YQRZ_155->getItem(clicked_item));

      int clicked_key = item->data_i;
      
      
      
       click_devopts_vol(clicked_key); 
      return 1;
    }








  


  




  long VFLL2::YQRZ_187
    (FXObject *object,FXSelector sel, void *arg)
       {  close_devopts(1);  return 1; }





  long VFLL2::YQRZ_192
    (FXObject *object,FXSelector sel, void *arg)
       { close_devopts(0);  return 1; }






  

 gui_ud_main_t *gui_c_ud_main()
 {
    // ffo -> fox form object
    // ifo -> interface form object 
   VFLL1 *ffo;
   gui_ud_main_t * ifo;
   ffo= new VFLL1(
       FXApp::instance(),
       "USB Disks",
       NULL, NULL, // FIXME: icons
       DECOR_ALL ,
       0, 0,
       400, 400,
       0, 0,
       0, 0,
       0, 0);
   // If the application has not been created, this will done
   // when the application gets created. Otherwise, we have
   // to explicitly do this.
   if (app_created) 
     ffo->create();
   
   ffo->show(PLACEMENT_SCREEN);

   ifo= (typeof(ifo)) malloc(sizeof(*ifo));
   ifo->self= ffo;
    



  
    ifo->ud_unmounted.cls= & gui_intlist_class;
    ifo->ud_unmounted.widget= ffo->ud_unmounted;
   

 


  
    ifo->ud_mounted.cls= & gui_intlist_class;
    ifo->ud_mounted.widget= ffo->ud_mounted;
   

 




 



 



 



 

 
 ifo->file_browser.widget= ffo->file_browser;
 ifo->file_browser.cls= &gui_text_entry_class;



 

 

 
 ifo->mount_prg.widget= ffo->mount_prg;
 ifo->mount_prg.cls= &gui_text_entry_class;


 


  
     ifo->opexec.widget= ffo->opexec;
     ifo->opexec.cls= &gui_check_box_class;
  



  
     ifo->opnoatime.widget= ffo->opnoatime;
     ifo->opnoatime.cls= &gui_check_box_class;
  

 



 






  ifo->message.widget= ffo->message;
  ifo->message.cls= &gui_message_console_class;



 






  ifo->about.widget= ffo->about;
  ifo->about.cls= &gui_message_console_class;


 



 




   return ifo;
 }


 

 gui_devopt_t *gui_c_devopt(void *owner)
 {
    // ffo -> fox form object
    // ifo -> interface form object 
   VFLL2 *ffo;
   gui_devopt_t * ifo;
   ffo= new VFLL2(
       (FXWindow*) owner,
       "Device Options",
       NULL, NULL, // FIXME: icons
        0  | DECOR_TITLE ,
       0, 0,
       400, 330,
       0, 0,
       0, 0,
       0, 0);

   ifo= (typeof(ifo)) malloc(sizeof(*ifo));
   ifo->self= ffo;
   ifo->cls= (YQRZ_195*) &gui_dialog_class;

    

 

 ifo->vendor.widget= ffo->vendor;
 ifo->vendor.cls= &gui_label_class;


 

 ifo->model.widget= ffo->model;
 ifo->model.cls= &gui_label_class;


 

 ifo->serial.widget= ffo->serial;
 ifo->serial.cls= &gui_label_class;


 

 
 ifo->pretty_name.widget= ffo->pretty_name;
 ifo->pretty_name.cls= &gui_text_entry_class;


 


  
    ifo->parts.cls= & gui_intlist_class;
    ifo->parts.widget= ffo->parts;
   

 

 ifo->selpart.widget= ffo->selpart;
 ifo->selpart.cls= &gui_label_class;


 

 
 ifo->mount_label.widget= ffo->mount_label;
 ifo->mount_label.cls= &gui_text_entry_class;



  
     ifo->opexec.widget= ffo->opexec;
     ifo->opexec.cls= &gui_check_box_class;
  


  
     ifo->opnoatime.widget= ffo->opnoatime;
     ifo->opnoatime.cls= &gui_check_box_class;
  

 



 





   return ifo;
 }




static FXApp *app;

void gui_init(int *argc,char **argv)
{
  app= new FXApp("YAK", "KUT");
  app->init(*argc, argv);
  app->create();
    // YQRZ_3->create(); 
      // YQRZ_7->create(); 
      // YQRZ_13->create(); 
      // YQRZ_17->create(); 
      // YQRZ_117->create(); 
      // YQRZ_148->create(); 
    
  app_created= 1;
}

void gui_run()
{
  app->run();
}

void gui_flush()
{
  app->runWhileEvents();
}



